.. _reference:

Reference
*********

.. toctree::
    introduction
    data
    topology
    path
    clustering
    hierarchy
    ranking
    classification
    embedding
    linkpred
    linalg
    utils
    visualization





